==> UPS-courier_v1.4.2.zip: UPS-courier v1.4.2/UPS-courier v1.4.2.oxp/Scripts/upsDerelict.js <==
this.name      = "upsderelict"; 
this.author    = "eric walch"; 
this.copyright = " 2008 the Oolite team."; 
this.version   = "1.01";

this.shipSpawned = function()
{
    this.ship.switchAI("derelictUpsJSAI.plist")
    this.collissionradius = 100
    this.shipName = this.ship.shipDisplayName
    this.countdown = 5
    this.maxFuel = 1
    delete this.shipSpawned;
}

this.checkFuel = function()
{
    if(player.fuel > 0) 
    {
        player.commsMessage("Help anyone, we are out of fuel.", 6)
    }
    else
    {
        this.ship.switchAI("route1TraderAI.plist")
    }
}

this.checkDistance = function()
{
  let distance = Math.round(player.position.distanceTo(this.ship))
  if (distance < 6000)
  {
  player.consoleMessage("You are on approach, lower your speed", 9)
  this.ship.shipDisplayName = this.shipName + " without fuel"
  this.ship.reactToAIMessage("UPS_PLAYER_APPROACHING")
  }
}

this.guideIn = function()
{
    let distance = Math.round(player.position.distanceTo(this.ship)) - this.collissionradius
    let speed = Math.round(player.speed)
    if (distance > 7000)
    {
        this.ship.reactToAIMessage("UPS_PLAYER_LEAVING"); return
    }
    if (distance > 1500)
    {
        if(speed > 100) player.consoleMessage("Approaching with: " + speed + "km/h, lower your speed.", 4)
    }
    else
    {
        if(speed > 50) player.consoleMessage("Approaching with: " + speed + "km/h, lower your speed to 50 km/h.", 4)
        player.consoleMessage("You are at " + distance + " meters, come to a complete standstill within 100 meters.", 4)
    }
    if(distance < 100 && player.speed == 0)
    {
        this.ship.reactToAIMessage("UPS_PLAYER_CLOSE");
    }
}

this.checkSpeed = function()
{
  if (player.speed > 5)
  {
    player.consoleMessage("You are moving to much, lower your speed", 4)
    this.ship.reactToAIMessage("UPS_PLAYER_APPROACHING");
    this.countdown = 5
  }
  else
  {
    player.consoleMessage("Transfering fuel..... " +this.countdown, 3)
    if(player.fuel > 0 && this.maxFuel > 0)
    {
    player.fuel -= 0.2
    this.maxFuel -= 0.2
    }
    this.countdown--
    if(this.countdown<0)
    {
        this.ship.reactToAIMessage("UPS_TRANSFERING")
    }
  }
}

this.thankPlayer = function()
{
    if(player.fuel > 0)
    {
        player.commsMessage(expandDescription("Thank you for the fuel [commanderShip_string]."), 6)
    }
    else
    {
        player.commsMessage(expandDescription("Thank you for giving you last bit of fuel [commanderShip_string]."), 6)
    }
    this.ship.shipDisplayName = this.shipName
}

this.tranferPayment = function()
{
    player.awardCargo("Gem-Stones", 50)
    missionVariables.ups_tcount++
}

==> UPS-courier_v1.4.3.zip: UPS-courier v1.4.3/UPS-courier v1.4.3.oxp/Scripts/upsDerelict.js <==
this.name      = "upsderelict"; 
this.author    = "eric walch"; 
this.copyright = " 2008 eric walch."; 
this.version   = "1.01";

this.shipSpawned = function()
{
    this.ship.switchAI("derelictUpsJSAI.plist")
    this.collissionradius = 100
    this.shipName = this.ship.shipDisplayName
    this.countdown = 5
    this.maxFuel = 1
    delete this.shipSpawned;
}

this.checkFuel = function()
{
    if(worldScripts["ups_container"].playerShip.fuel > 0) 
    {
        player.commsMessage("Help anyone, we are out of fuel.", 6)
    }
    else
    {
        this.ship.switchAI("route1TraderAI.plist")
    }
}

this.checkDistance = function()
{
  let distance = Math.round(worldScripts["ups_container"].playerShip.position.distanceTo(this.ship))
  if (distance < 6000)
  {
  player.consoleMessage("You are on approach, lower your speed", 9)
  this.ship.shipDisplayName = this.shipName + " without fuel"
  this.ship.reactToAIMessage("UPS_PLAYER_APPROACHING")
  }
}

this.guideIn = function()
{
    let distance = Math.round(worldScripts["ups_container"].playerShip.position.distanceTo(this.ship)) - this.collissionradius
    let speed = Math.round(worldScripts["ups_container"].playerShip.speed)
    if (distance > 7000)
    {
        this.ship.reactToAIMessage("UPS_PLAYER_LEAVING"); return
    }
    if (distance > 1500)
    {
        if(speed > 100) player.consoleMessage("Approaching with: " + speed + "km/h, lower your speed.", 4)
    }
    else
    {
        if(speed > 50) player.consoleMessage("Approaching with: " + speed + "km/h, lower your speed to 50 km/h.", 4)
        player.consoleMessage("You are at " + distance + " meters, come to a complete standstill within 100 meters.", 4)
    }
    if(distance < 100 && worldScripts["ups_container"].playerShip.speed == 0)
    {
        this.ship.reactToAIMessage("UPS_PLAYER_CLOSE");
    }
}

this.checkSpeed = function()
{
  if (player.speed > 5)
  {
    player.consoleMessage("You are moving to much, lower your speed", 4)
    this.ship.reactToAIMessage("UPS_PLAYER_APPROACHING");
    this.countdown = 5
  }
  else
  {
    player.consoleMessage("Transfering fuel..... " +this.countdown, 3)
    if(worldScripts["ups_container"].playerShip.fuel > 0 && this.maxFuel > 0)
    {
    worldScripts["ups_container"].playerShip.fuel -= 0.2
    this.maxFuel -= 0.2
    }
    this.countdown--
    if(this.countdown<0)
    {
        this.ship.reactToAIMessage("UPS_TRANSFERING")
    }
  }
}

this.thankPlayer = function()
{
    if(worldScripts["ups_container"].playerShip.fuel > 0)
    {
        player.commsMessage(expandDescription("Thank you for the fuel [commanderShip_string]."), 6)
    }
    else
    {
        player.commsMessage(expandDescription("Thank you for giving you last bit of fuel [commanderShip_string]."), 6)
    }
    this.ship.shipDisplayName = this.shipName
}

this.tranferPayment = function()
{
    worldScripts["ups_container"].playerShip.awardCargo("Gem-Stones", 50)
    // pro memory, 1.72 will have: canAwardCargo("Gem-Stones", 50), true/false
    missionVariables.ups_tcount++
}
